.. :changelog:

Release History
---------------

1.1 (2014-05-12)
++++++++++++++++

- Add e-mail notifications for simple infrastructures without a monitoring server.
- Move config files in **input/** and **output/** to be easier to understand.
- Reduce command line arguments for config files.

1.0 (2014-05-06)
++++++++++++++++

- Change **nagios_plugins.cfg** syntax to give directly the command line to launch.
- Add **servers** list parameter in **nagios_plugins.cfg** to define the servers list that must receive configuration.
- Logging improvements
- Rename **eyepea_monitoring_agent** to **Tanto**, a short blade in the same family as **Shinken**.

0.9 (2012-08-14)
++++++++++++++++

First public release.